package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.NotifyOrderMapper;
import com.ruoyi.system.domain.NotifyOrder;
import com.ruoyi.system.service.INotifyOrderService;

/**
 * 订单电话通知师傅记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class NotifyOrderServiceImpl implements INotifyOrderService 
{
    @Autowired
    private NotifyOrderMapper notifyOrderMapper;

    /**
     * 查询订单电话通知师傅记录
     * 
     * @param id 订单电话通知师傅记录主键
     * @return 订单电话通知师傅记录
     */
    @Override
    public NotifyOrder selectNotifyOrderById(Long id)
    {
        return notifyOrderMapper.selectNotifyOrderById(id);
    }

    public  int  selectNotifyOrderCountByOid(long oid){
        return notifyOrderMapper.selectNotifyOrderCountByOid(oid);
    }


    public List<NotifyOrder> selectNotifyOrderByOid(long oid) {
         return notifyOrderMapper.selectNotifyOrderByOid(oid);
    }


    /**
     * 查询订单电话通知师傅记录列表
     * 
     * @param notifyOrder 订单电话通知师傅记录
     * @return 订单电话通知师傅记录
     */
    @Override
    public List<NotifyOrder> selectNotifyOrderList(NotifyOrder notifyOrder)
    {
        return notifyOrderMapper.selectNotifyOrderList(notifyOrder);
    }

    /**
     * 新增订单电话通知师傅记录
     * 
     * @param notifyOrder 订单电话通知师傅记录
     * @return 结果
     */
    @Override
    public int insertNotifyOrder(NotifyOrder notifyOrder)
    {
        return notifyOrderMapper.insertNotifyOrder(notifyOrder);
    }

    /**
     * 修改订单电话通知师傅记录
     * 
     * @param notifyOrder 订单电话通知师傅记录
     * @return 结果
     */
    @Override
    public int updateNotifyOrder(NotifyOrder notifyOrder)
    {
        return notifyOrderMapper.updateNotifyOrder(notifyOrder);
    }

    /**
     * 批量删除订单电话通知师傅记录
     * 
     * @param ids 需要删除的订单电话通知师傅记录主键
     * @return 结果
     */
    @Override
    public int deleteNotifyOrderByIds(Long[] ids)
    {
        return notifyOrderMapper.deleteNotifyOrderByIds(ids);
    }

    /**
     * 删除订单电话通知师傅记录信息
     * 
     * @param id 订单电话通知师傅记录主键
     * @return 结果
     */
    @Override
    public int deleteNotifyOrderById(Long id)
    {
        return notifyOrderMapper.deleteNotifyOrderById(id);
    }
}
