package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.NotifyOrder;
import com.ruoyi.system.service.INotifyOrderService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单电话通知师傅记录Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/NotifyOrder")
public class NotifyOrderController extends BaseController
{
    @Autowired
    private INotifyOrderService notifyOrderService;

    /**
     * 查询订单电话通知师傅记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:NotifyOrder:list')")
    @GetMapping("/list")
    public TableDataInfo list(NotifyOrder notifyOrder)
    {
        startPage();
        List<NotifyOrder> list = notifyOrderService.selectNotifyOrderList(notifyOrder);
        return getDataTable(list);
    }

    /**
     * 导出订单电话通知师傅记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:NotifyOrder:export')")
    @Log(title = "订单电话通知师傅记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, NotifyOrder notifyOrder)
    {
        List<NotifyOrder> list = notifyOrderService.selectNotifyOrderList(notifyOrder);
        ExcelUtil<NotifyOrder> util = new ExcelUtil<NotifyOrder>(NotifyOrder.class);
        util.exportExcel(response, list, "订单电话通知师傅记录数据");
    }

    /**
     * 获取订单电话通知师傅记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:NotifyOrder:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(notifyOrderService.selectNotifyOrderById(id));
    }

    /**
     * 新增订单电话通知师傅记录
     */
    @PreAuthorize("@ss.hasPermi('system:NotifyOrder:add')")
    @Log(title = "订单电话通知师傅记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody NotifyOrder notifyOrder)
    {
        return toAjax(notifyOrderService.insertNotifyOrder(notifyOrder));
    }

    /**
     * 修改订单电话通知师傅记录
     */
    @PreAuthorize("@ss.hasPermi('system:NotifyOrder:edit')")
    @Log(title = "订单电话通知师傅记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody NotifyOrder notifyOrder)
    {
        return toAjax(notifyOrderService.updateNotifyOrder(notifyOrder));
    }

    /**
     * 删除订单电话通知师傅记录
     */
    @PreAuthorize("@ss.hasPermi('system:NotifyOrder:remove')")
    @Log(title = "订单电话通知师傅记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(notifyOrderService.deleteNotifyOrderByIds(ids));
    }
}
